<?php

require_once('Config.inc');

/**
 * make select
 *
 * function to make a select from give values
 *
 * @param	string	$name	name for select
 * @param	array	$values	 associative array, indexes are values, values are labels
 * @param	string	$selected	optional - selected values
 * @param	bool	$same	optional - use array values as keys as well
 * @param	string	$options	optional - options to put in select tag (ie onchange etc)
 * @access	public
 * @return	string	$html
 */
function make_select($name, $values, $selected='', $same=FALSE, $options='') {
	$return_val = "<select name=\"${name}\"" . (empty($options) ? "" : $options) . ">\n";
	
	// here we add the empty string to all values to do an implicit
	// type conversion, as htmlentities expects a string
	foreach ($values as $key => $value) {
		$return_val .= "<option value=\"" . htmlentities(($same ? $value : $key) . "") . "\"" . (($same ? $value : $key) == $selected ? " selected=\"selected\"" : "") . ">" . htmlentities($value . "") . "</option>\n";
	}
	
	$return_val .= "</select>\n";	
		
	return ($return_val);
}


/**
 * encrypt
 *
 * @param	string	$text	text to encrypt
 * @access	public
 * @return	string	$encrypted_text
 */
function encrypt($text) {
	return(base64_encode(mcrypt_ecb(MCRYPT_BLOWFISH_448, HELP_PRIVATE_KEY, $text, MCRYPT_ENCRYPT)));
}


/**
 * decrypt
 *
 * @param	string	$encrypted_text	text to decrypt
 * @access	public
 * @return	string	$text
 */
function decrypt($text) {
	return(mcrypt_ecb(MCRYPT_BLOWFISH_448, HELP_PRIVATE_KEY, base64_decode($text), MCRYPT_DECRYPT));
}


/**
 * if unset define
 *
 * define spits out errors if the definition already exists
 * this is not always what one wants
 *
 * @param	string	$name
 * @param	string	$value
 * @access	public
 * @return	bool	$defined
 */
function if_unset_define($name, $value) {
	if (defined($name)) {
		return TRUE;
	}
	else {
		define($name, $value);
		return FALSE;
	}
}


/**
 * error screen
 *
 * Screen which displays errors
 *
 * @param	string	$error	optional - error to display
 * @access	public
 * @return	html	$output
 */
function &error_screen($error='') {

	include_once('Type.class');

	$type = new Type();

	if (!$type->check($error, 'string', array('minimum' => 1, 'maximum' => 200))) {
		$error = "An unknown error has occurred";
	}

	$body = "<p class=\"error\">" . htmlentities($error) . "</p>";

	return ($body);
}


/**
 * Nest Array 
 *
 * Returns an array formatted nicely
 * 
 * @param	array	$array
 * @param	int	$nesting
 * @access	public
 * @return	string	$values	array as string
 */
function nest_array($array, $nesting=0) {

	$output_string = '';

	if (is_array($array)) {
		foreach ($array as $key => $value) {
			$output_string .= str_repeat("\t", $nesting) . "$key => $value\n";

			if (is_array($value)) {
				$output_string .= nest_array($value, $nesting + 1); 
			}
		}
	}

	return ($output_string);
}


/**
 * make_url
 *
 * creates a url to the given class, command etc
 * 
 * @param	string $class	class name   
 * @param	string $command	command to perform   
 * @param	array $extras	optional - key => value listing of extra link parameters   
 * @access	public
 * @return	string	$url
 */
function make_url($class, $command, $extras='') {
	$query_string_extras = '';
	
	if (is_array($extras)) {
		foreach ($extras as $ex_key => $ex_value) {
			$query_string_extras .= "&" . urlencode($ex_key) . "=" . urlencode($ex_value);
		}
	}
	
	$return_link = "http://" . WEB_BASE . "?class=" . urlencode($class) . "&command=" . urlencode($command) . $query_string_extras;

	return ($return_link);
}


/**
 * make_link
 *
 * creates a link to the given class, command etc
 * 
 * @param	string $link_text	text for link to display
 * @param	string $class	class name   
 * @param	string $command	command to perform   
 * @param	array $extras	optional - key => value listing of extra link parameters   
 * @access	public
 * @return	string	$application_link
 */
function make_link($link_text, $class, $command, $extras='') {
	$return_link = "<a href=\"" . make_url($class, $command, $extras) . "\" class=\"link\">" . htmlentities($link_text) . "</a>";

	return ($return_link);
}


/**
 * make_link_confirm
 *
 * creates a link to the given class, command etc
 * 
 * @param	string $link_text	text for link to display
 * @param	string $class	class name   
 * @param	string $command	command to perform   
 * @param	string $confirm_text	text to show to user
 * @param	array $extras	optional - key => value listing of extra link parameters   
 * @access	public
 * @return	string	$application_link
 */
function make_link_confirm($link_text, $class, $command, $confirm_text, $extras='') {
	
	$return_link = "<a href=\"" . make_url($class, $command, $extras) . "\" class=\"link\" onclick=\"return confirm('" . htmlentities($confirm_text) . "');\">" . htmlentities($link_text) . "</a>";

	return ($return_link);
}

?>
